Learn R Programming

iemisctext (version 1.0.0)

appeal_womanhood_world: Appeal to Womanhood Throughout the World

Description

A dataset which contains one document written by Julia Ward Howe that asks that Christian women all over the world come together to start a movement for global peace and unity.

Usage

appeal_womanhood_world

Arguments

Format

A VCorpus of 1 text document.