Learn R Programming

iemisctext (version 1.0.0)

climate_strange: Untitled: Climate Strange

Description

A dataset which contains one poem written by Irucka Ajani Embry that challenges the nature of Reality and the expressions of material science (Eugenics, Genetic Engineering, Global Warming, etc.).

Usage

climate_strange

Arguments

Format

A VCorpus of 1 text document.