Learn R Programming

iemisctext (version 1.0.0)

connect_dots: Connect the D.O.T.S.

Description

A dataset which contains a piece written by Obiora Embry in April 2006. It was written to help wake up consumers and empower them with knowledge to invoke change from automobile manufacturers and within society by connecting various dots.

Usage

connect_dots

Arguments

Format

A VCorpus of 1 text document.