Learn R Programming

iemisctext (version 1.0.0)

us_them: Untitled: Us versus Them or People Screwing over Other People

Description

A dataset which contains one poem written by Irucka Ajani Embry that challenges the ideas of "us versus them" through a variety of examples.

Usage

us_them

Arguments

Format

A VCorpus of 1 text document.